package com.zjsgfa.project.zjsgfa.mapper;

import java.util.List;
import com.zjsgfa.project.zjsgfa.domain.SjFdsgcsDcyxt;

/**
 * 地层压力图Mapper接口
 * 
 * @author ruoyi
 * @date 2025-12-09
 */
public interface SjFdsgcsDcyxtMapper 
{
    /**
     * 查询地层压力图
     * 
     * @param id 地层压力图主键
     * @return 地层压力图
     */
    public SjFdsgcsDcyxt selectSjFdsgcsDcyxtById(Long id);

    /**
     * 查询地层压力图列表
     * 
     * @param sjFdsgcsDcyxt 地层压力图
     * @return 地层压力图集合
     */
    public List<SjFdsgcsDcyxt> selectSjFdsgcsDcyxtList(SjFdsgcsDcyxt sjFdsgcsDcyxt);

    /**
     * 新增地层压力图
     * 
     * @param sjFdsgcsDcyxt 地层压力图
     * @return 结果
     */
    public int insertSjFdsgcsDcyxt(SjFdsgcsDcyxt sjFdsgcsDcyxt);

    /**
     * 修改地层压力图
     * 
     * @param sjFdsgcsDcyxt 地层压力图
     * @return 结果
     */
    public int updateSjFdsgcsDcyxt(SjFdsgcsDcyxt sjFdsgcsDcyxt);

    /**
     * 删除地层压力图
     * 
     * @param id 地层压力图主键
     * @return 结果
     */
    public int deleteSjFdsgcsDcyxtById(Long id);

    /**
     * 批量删除地层压力图
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSjFdsgcsDcyxtByIds(Long[] ids);

    int  deleteSjFdsgcsDcyxtByZbid(String zbid);
}
